<?php
namespace Widerheim\WhSaveButtons\Hooks;

use TYPO3\CMS\Backend\Template\Components\Buttons\InputButton;
use TYPO3\CMS\Backend\Template\Components\Buttons\SplitButton;
use TYPO3\CMS\Core\Exception;

/**
 * Add an extra save and close button at the end
 *
 * Class SaveButtonHook
 * @package Widerheim\WhSaveButtons\Hooks
 */
Class SaveButtonsHook
{
    /**
     * @var int The position of the save SplitButton
     */
    protected $index = 2;

    /**
     * @param array $params
     * @param $ref
     * @throws Exception
     * @return array
     */
    public function revertSaveButtons($params, &$ref)
    {
        if (!isset($params['buttons']['left'])) {
            // something is wrong here, bail.
            return $params['buttons'];
        }
        $buttons = $params['buttons']['left'];

        $secondarySaveButtons = $this->getSecondarySaveButtons($buttons);
        if (!$secondarySaveButtons) {
            return $params['buttons'];
        }

        // save changes by reference
        array_splice($params['buttons']['left'], $this->index, 0, array(array($secondarySaveButtons[0]), array($secondarySaveButtons[1])));

        return $params['buttons'];
    }

    /**
     * @param array $buttons
     * @return InputButton
     * @throws Exception
     */
    private function getSecondarySaveButtons($buttons)
    {
        try {
            /** @var SplitButton $splitButton */
            $splitButton = $buttons[$this->index][0];
            if (!isset($splitButton)) {
                return null;
            }
            $subButtons = $splitButton->getButton();

            /** @var InputButton $primaryButton */
            $primaryButton = $subButtons['primary'];

            if ($primaryButton->getName() == '_savedok') {
                return $subButtons['options'];
            } else {
                // parse the entire button bar for the save and clone butten. where is it? WHERE IS IT?
                return null;
            }
        } catch (Exception $e) {
            throw new Exception('Couldn\'t find the save and close button.');
        }
    }
}